==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/sv.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Bildgalleri",
    "There was a problem reading files from this album" : "Det uppstod ett problem vid inläsning av filer från detta album",
    "Aborting preview. Could not find the file" : "Avbryter förhandsgranskning. Kunde inte hitta filen",
    "Could not move \"{file}\", target exists" : "Kunde inte flytta \"{file}\", filen existerar redan",
    "Could not move \"{file}\"" : "Kunde inte flytta \"{file}\"",
    "No compatible server found at {remote}" : "Ingen kompatibel server hittad hos {remote}",
    "Invalid server url" : "Ogiltig server-url",
    "Could not load the description" : "Kunde inte ladda beskrivningen",
    "Could not load the description: " : "Kunde inte ladda beskrivningen:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Kunde inte ladda Copyright notis:",
    "Copyright notice" : "Copyright notis",
    "Link to copyright document" : "Länk till Copyright dokumentation",
    "This application may not work properly on your browser." : "Denna applikation kanske inte fungerar som den ska i din webbläsare.",
    "For an improved experience, please install one of the following alternatives" : "För en förbättrad upplevelse, var god installera ett av följande alternativ",
    "Your browser is not supported!" : "Din webbläsare stöds ej!",
    "please install one of the following alternatives" : "Var god installera ett av följande alternativ",
    "Album cannot be shown" : "Album kan ej visas",
    "No media files found" : "Inga media-filer kunde hittas",
    "Upload pictures in the Files app to display them here" : "Ladda upp bilder i appen Filer för att visa dom här",
    "Upload new files via drag and drop or by using the [+] button above" : "Ladda upp nya filer genom att dra och släppa eller genom att använda [+] knappen ovan",
    "Configuration error" : "Konfigurationsfel",
    "New" : "Ny",
    "Hide Album" : "Dölj Album",
    "Could not hide album" : "Kunde inte dölja album",
    "Error loading slideshow template" : "Fel vid laddning av mallen för bildspelet",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Fel!</strong> Kunde inte skapa en förhandsgranskning av den här filen.<br>Vänligen gå till nästa bild medan vi tar bort den här bilden från bildspelet",
    "Next" : "Nästa",
    "Play" : "Spela",
    "Pause" : "Pausa",
    "Previous" : "Föregående",
    "Close" : "Stäng",
    "Download" : "Ladda ned",
    "Toggle background" : "Växla bakgrund",
    "Delete" : "Radera",
    "Share" : "Dela",
    "Could not create file \"{file}\" because it already exists" : "Kunde inte skapa fil \"{file}\" eftersom den redan finns",
    "Could not create file \"{file}\"" : "Kunde inte skapa fil \"{fileName}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltligt filnamn.",
    "File name cannot be empty." : "Filnamnet kan inte vara tomt.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" är inte en tillåten filtyp",
    "Upload" : "Ladda upp",
    "Error" : "Fel",
    "Error while sharing" : "Fel vid delning",
    "Error while unsharing" : "Fel när delning skulle avslutas",
    "Error while changing permissions" : "Fel vid ändring av behörigheter",
    "Shared with you and the group {group} by {owner}" : "Delad med dig och gruppen {group} av {owner}",
    "Shared with you by {owner}" : "Delad med dig av {owner}",
    "Share with users or groups …" : "Dela med användare eller grupper ...",
    "Share with users, groups or remote users …" : "Dela med användare, grupper eller externanvändare ...",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Dela med personer på andra servrar genom att använda deras Federerade Moln-ID användarnamn@exempel.se/cloud",
    "Share link" : "Dela länk",
    "The public link will expire no later than {days} days after it is created" : "Den offentliga länken kommer sluta att gälla {days} dagar efter att den skapades",
    "Link" : "Länk",
    "Password protect" : "Lösenordsskydda",
    "Password" : "Lösenord",
    "Choose a password for the public link" : "Välj ett lösenord för den offentliga länken",
    "Allow editing" : "Tillåt redigering",
    "Email link to person" : "E-posta länk till person",
    "Send" : "Skicka",
    "Set expiration date" : "Sätt utgångsdatum",
    "Expiration" : "Upphör",
    "Expiration date" : "Utgångsdatum",
    "This list is maybe truncated - please refine your search term to see more results." : "Listan kan vara ofullständig - specificera din sökning för att se mer resultat.",
    "No users or groups found for {search}" : "Inga användare eller grupper hittades med sökningen {search}",
    "No users found for {search}" : "Inga användare hittades med sökningen {search}",
    "An error occured. Please try again" : "Ett fel uppstod. Var god försök igen",
    "Adding user..." : "Lägger till användare...",
    "group" : "Grupp",
    "remote" : "extern",
    "Resharing is not allowed" : "Dela vidare är inte tillåtet",
    "Error while retrieving shares" : "Fel uppstod vid inhämtning av delningar",
    "Unshare" : "Sluta dela",
    "notify by email" : "informera via e-post",
    "can share" : "får dela",
    "can edit" : "kan redigera",
    "access control" : "åtkomstkontroll",
    "create" : "skapa",
    "change" : "redigera",
    "delete" : "radera",
    "Password protected" : "Lösenordsskyddad",
    "Error unsetting expiration date" : "Fel vid borttagning av utgångsdatum",
    "Error setting expiration date" : "Fel vid val av utgångsdatum",
    "Sending ..." : "Skickar ...",
    "Email sent" : "E-post skickat",
    "Warning" : "Varning",
    "This share is password-protected" : "Den här delningen är lösenordsskyddad",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Sort by name" : "Sortera efter namn",
    "Sort by date" : "Sortera efter datum",
    "Cancel upload" : "Avbryt uppladdning",
    "Album information" : "Information om album",
    "File list" : "Filbibliotek",
    "Sorry, this file could not be found." : "Tyvärr, denna filen kunde inte hittas.",
    "Reasons might be:" : "Orsaker kan vara:",
    "the wrong file ID was provided" : "Fel fil-ID angavs",
    "the file was removed" : "Filen blev borttagen",
    "the file is corrupt" : "Denna fil är korrupt",
    "the encryption key is missing" : "Krypteringsnyckel saknas",
    "Here is the error message returned by the server: " : "Här är felkoden som servern svarade med:",
    "For more information, please contact your friendly Nextcloud administrator." : "För mer information var god kontakta din administratör.",
    "Sorry, but the server could not fulfill your request." : "Tyvärr, servern kunde inte fullfölja din förfrågan.",
    "Possible reasons for the problem:" : "Sannolika orsaker till detta problem:",
    "a conflicting app was installed" : "En motstridig applikation har installerats",
    "a required component is missing or was disconnected" : "En behövd komponent saknas eller har inaktiverats",
    "the filesystem is not readable" : "filsystemet är ej läsbart",
    "Sorry, this link doesn't seem to work anymore." : "Tyvärr, denna länk verkar inte fungera längre.",
    "the item was removed" : "objektet togs bort",
    "the link has expired" : "tidsgräns för länken har löpt ut",
    "sharing is disabled" : "delning är inaktiverat",
    "For more information, please ask the person who has sent you this link." : "För mer information, var god fråga den person som skickat dig länken",
    "Add to your Nextcloud" : "Lägg till till din Nextcloud",
    "Picture view" : "Bildvy",
    "Gallery view" : "Bildgallerivy"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/sv.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Bildgalleri",
    "There was a problem reading files from this album" : "Det uppstod ett problem vid inläsning av filer från detta album",
    "Aborting preview. Could not find the file" : "Avbryter förhandsgranskning. Kunde inte hitta filen",
    "Could not move \"{file}\", target exists" : "Kunde inte flytta \"{file}\", filen existerar redan",
    "Could not move \"{file}\"" : "Kunde inte flytta \"{file}\"",
    "No compatible server found at {remote}" : "Ingen kompatibel server hittad hos {remote}",
    "Invalid server url" : "Ogiltig server-url",
    "Could not load the description" : "Kunde inte ladda beskrivningen",
    "Could not load the description: " : "Kunde inte ladda beskrivningen:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Kunde inte ladda Copyright notis:",
    "Copyright notice" : "Copyright notis",
    "Link to copyright document" : "Länk till Copyright dokumentation",
    "This application may not work properly on your browser." : "Denna applikation kanske inte fungerar som den ska i din webbläsare.",
    "For an improved experience, please install one of the following alternatives" : "För en förbättrad upplevelse, var god installera ett av följande alternativ",
    "Your browser is not supported!" : "Din webbläsare stöds ej!",
    "please install one of the following alternatives" : "Var god installera ett av följande alternativ",
    "Album cannot be shown" : "Album kan ej visas",
    "No media files found" : "Inga media-filer kunde hittas",
    "Upload pictures in the Files app to display them here" : "Ladda upp bilder i appen Filer för att visa dom här",
    "Upload new files via drag and drop or by using the [+] button above" : "Ladda upp nya filer genom att dra och släppa eller genom att använda [+] knappen ovan",
    "Configuration error" : "Konfigurationsfel",
    "New" : "Ny",
    "Hide Album" : "Dölj Album",
    "Could not hide album" : "Kunde inte dölja album",
    "Error loading slideshow template" : "Fel vid laddning av mallen för bildspelet",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Fel!</strong> Kunde inte skapa en förhandsgranskning av den här filen.<br>Vänligen gå till nästa bild medan vi tar bort den här bilden från bildspelet",
    "Next" : "Nästa",
    "Play" : "Spela",
    "Pause" : "Pausa",
    "Previous" : "Föregående",
    "Close" : "Stäng",
    "Download" : "Ladda ned",
    "Toggle background" : "Växla bakgrund",
    "Delete" : "Radera",
    "Share" : "Dela",
    "Could not create file \"{file}\" because it already exists" : "Kunde inte skapa fil \"{file}\" eftersom den redan finns",
    "Could not create file \"{file}\"" : "Kunde inte skapa fil \"{fileName}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltligt filnamn.",
    "File name cannot be empty." : "Filnamnet kan inte vara tomt.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" är inte en tillåten filtyp",
    "Upload" : "Ladda upp",
    "Error" : "Fel",
    "Error while sharing" : "Fel vid delning",
    "Error while unsharing" : "Fel när delning skulle avslutas",
    "Error while changing permissions" : "Fel vid ändring av behörigheter",
    "Shared with you and the group {group} by {owner}" : "Delad med dig och gruppen {group} av {owner}",
    "Shared with you by {owner}" : "Delad med dig av {owner}",
    "Share with users or groups …" : "Dela med användare eller grupper ...",
    "Share with users, groups or remote users …" : "Dela med användare, grupper eller externanvändare ...",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Dela med personer på andra servrar genom att använda deras Federerade Moln-ID användarnamn@exempel.se/cloud",
    "Share link" : "Dela länk",
    "The public link will expire no later than {days} days after it is created" : "Den offentliga länken kommer sluta att gälla {days} dagar efter att den skapades",
    "Link" : "Länk",
    "Password protect" : "Lösenordsskydda",
    "Password" : "Lösenord",
    "Choose a password for the public link" : "Välj ett lösenord för den offentliga länken",
    "Allow editing" : "Tillåt redigering",
    "Email link to person" : "E-posta länk till person",
    "Send" : "Skicka",
    "Set expiration date" : "Sätt utgångsdatum",
    "Expiration" : "Upphör",
    "Expiration date" : "Utgångsdatum",
    "This list is maybe truncated - please refine your search term to see more results." : "Listan kan vara ofullständig - specificera din sökning för att se mer resultat.",
    "No users or groups found for {search}" : "Inga användare eller grupper hittades med sökningen {search}",
    "No users found for {search}" : "Inga användare hittades med sökningen {search}",
    "An error occured. Please try again" : "Ett fel uppstod. Var god försök igen",
    "Adding user..." : "Lägger till användare...",
    "group" : "Grupp",
    "remote" : "extern",
    "Resharing is not allowed" : "Dela vidare är inte tillåtet",
    "Error while retrieving shares" : "Fel uppstod vid inhämtning av delningar",
    "Unshare" : "Sluta dela",
    "notify by email" : "informera via e-post",
    "can share" : "får dela",
    "can edit" : "kan redigera",
    "access control" : "åtkomstkontroll",
    "create" : "skapa",
    "change" : "redigera",
    "delete" : "radera",
    "Password protected" : "Lösenordsskyddad",
    "Error unsetting expiration date" : "Fel vid borttagning av utgångsdatum",
    "Error setting expiration date" : "Fel vid val av utgångsdatum",
    "Email sent" : "E-post skickat",
    "Warning" : "Varning",
    "This share is password-protected" : "Den här delningen är lösenordsskyddad",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Sort by name" : "Sortera efter namn",
    "Sort by date" : "Sortera efter datum",
    "Cancel upload" : "Avbryt uppladdning",
    "Album information" : "Information om album",
    "File list" : "Filbibliotek",
    "Sorry, this file could not be found." : "Tyvärr, denna filen kunde inte hittas.",
    "Reasons might be:" : "Orsaker kan vara:",
    "the wrong file ID was provided" : "Fel fil-ID angavs",
    "the file was removed" : "Filen blev borttagen",
    "the file is corrupt" : "Denna fil är korrupt",
    "the encryption key is missing" : "Krypteringsnyckel saknas",
    "Here is the error message returned by the server: " : "Här är felkoden som servern svarade med:",
    "For more information, please contact your friendly Nextcloud administrator." : "För mer information var god kontakta din administratör.",
    "Sorry, but the server could not fulfill your request." : "Tyvärr, servern kunde inte fullfölja din förfrågan.",
    "Possible reasons for the problem:" : "Sannolika orsaker till detta problem:",
    "a conflicting app was installed" : "En motstridig applikation har installerats",
    "a required component is missing or was disconnected" : "En behövd komponent saknas eller har inaktiverats",
    "the filesystem is not readable" : "filsystemet är ej läsbart",
    "Sorry, this link doesn't seem to work anymore." : "Tyvärr, denna länk verkar inte fungera längre.",
    "the item was removed" : "objektet togs bort",
    "the link has expired" : "tidsgräns för länken har löpt ut",
    "sharing is disabled" : "delning är inaktiverat",
    "For more information, please ask the person who has sent you this link." : "För mer information, var god fråga den person som skickat dig länken",
    "Add to your Nextcloud" : "Lägg till till din Nextcloud",
    "Picture view" : "Bildvy",
    "Gallery view" : "Bildgallerivy",
    "Sending ..." : "Skickar ..."
},
"nplurals=2; plural=(n != 1);");
